import React, { useContext } from 'react';
import { TUIGlobal, CallRole, t } from '../../../../TUICallService';
import Avatar from '../../base/Avatar';
import Icon from '../../base/Icon/Icon';
import OverlayStream from '../../common/OverlayStream/OverlayStream';
import CallerUserInfoContext from '../../../context/CallerUserInfoContext';
import defaultAvatarSrc from '../../../assets/common/defaultAvatar.svg';
import './Waiting.less';

interface IWaitingProps {
  remoteList: Object[];
  callRole: CallRole;
}

export default function Waiting(props: IWaitingProps) {
  const { remoteList } = props;
  const callerUserInfo = useContext(CallerUserInfoContext);
  const { avatar, userId } = callerUserInfo || {};

  function WaitingH5() {
    const avatarIcon = <Icon style={{ width: '100%', height: '100%' }} url={defaultAvatarSrc} />;
    return (
      <OverlayStream
        className='groupcall-waiting-container waiting-mobile'
        showLoading={false}
        showAvatar
        blur
        tip={t('Invited group call')}
        showUsername
        username={userId}
        avatar={avatar || defaultAvatarSrc}
        theme={TUIGlobal.isPC ? 'circle' : 'dot'}
        isMobile={!TUIGlobal.isPC}
      >
        <div className='groupcall-info'>
          <div className='tip'>
            {remoteList.length}
            {t('people in the call')}
            :
          </div>
          <div className='avatar-group'>
            {remoteList?.map(() => <Avatar className='avatar-item' icon={avatarIcon} />)}
          </div>
        </div>
      </OverlayStream>
    );
  }
  function WaitingPC() {
    return (
      <OverlayStream
        className='groupcall-waiting-container'
        showLoading={false}
        avatar={avatar || defaultAvatarSrc}
        username={userId}
        showAvatar={!TUIGlobal.isPC}
        isMobile={!TUIGlobal.isPC}
        tip={t('Invited group call')}
      />
    );
  }

  return TUIGlobal.isPC ? <WaitingPC /> : <WaitingH5 />;
}
