import React, { useContext } from 'react';
import { CallStatus, TUIGlobal } from '../../../TUICallService';
import TopBar from '../common/TopBar/TopBar';
import ButtonPanel from '../common/ButtonPanel';
import Waiting from './Waiting/Waiting';
import { CallInfoContext, UserInfoContext } from '../../context';
import MediaContainer from './MediaContainer';
import { classNames } from '../../util/classnames';
import Tip from '../common/Tip/Tip';
import './SingleCall.less';

const SingleCall = React.memo(() => {
  const { remoteList } = useContext(UserInfoContext);
  const { callRole, callStatus, isFloat } = useContext(CallInfoContext);
  const classnames = classNames([
    'single-container',
    { mobile: !TUIGlobal.isPC },
  ]);

  const renderTopBar = () => {
    if (!isFloat) {
      return <TopBar />;
    }
  };
  const renderWaiting = () => {
    if (callStatus === CallStatus.CALLING && !isFloat) {
      return (
        <Waiting
          avatar={remoteList?.[0]?.avatar}
          username={remoteList?.[0]?.displayUserInfo}
          callRole={callRole}
        />
      );
    }
  };
  const renderButtonPanel = () => {
    if (!isFloat) {
      return <ButtonPanel />;
    }
  };

  return (
    <div className={classnames}>
      {renderTopBar()}
      {renderWaiting()}
      <MediaContainer />
      <Tip className='singlecall-tip' />
      {renderButtonPanel()}
    </div>
  );
});

export default SingleCall;
