/* eslint-disable react/jsx-no-constructed-context-values */
import React, {
  useMemo, useState, createContext, useEffect,
} from 'react';
import { classNames } from '../../../util/classnames';
import { classPrefix } from '../../../const/common';
import './ToggleWindow.less';

function getNonSpecifiedElement<T>(array: T[], specified: T) {
  for (let i = 0; i < array.length; i++) {
    if (array[i] !== specified) {
      return array[i];
    }
  }
}

export const ToggleWindowContext = createContext({ currentFocus: null });
interface IToggleWindowProps {
  focus: string;
  className?: string;
  isMobile?: boolean;
  showSmallWindow?: boolean;
  children?: any;
  onToggle?: (r?: any) => any;
}
export function ToggleWindow(props: IToggleWindowProps) {
  const {
    focus, className, isMobile, showSmallWindow = true, onToggle, children = null,
  } = props;
  const [currentFocus, setCurrentFocus] = useState(focus);

  useEffect(() => {
    setCurrentFocus(focus);
  }, [focus]);

  const classnames = classNames([
    `${classPrefix}-togglewindow-container`,
    className,
  ]);

  const filterChildren = useMemo(() => {
    let rs: any[] = [];
    const values: string[] = [];

    if (children) {
      React.Children.map(children, (child) => {
        if (child?.type?.displayName === 'ToggleWindowItem' && rs.length < 2) {
          // @ts-ignore
          rs.push(React.cloneElement(child, { isMobile, showSmallWindow }));
          values.push(child?.props?.value);
        }

        if (rs.length >= 2) {
          return null;
        }
      });
    }

    const updateCurrentFocus = () => {
      setCurrentFocus((state) => {
        const result = getNonSpecifiedElement<string>(values, state);
        onToggle?.(result);
        return result;
      });
    };
    rs = rs.map(
      (child, index) => React.cloneElement(child, { focus, updateCurrentFocus, key: index }),
    );
    return rs;
  }, [children, focus]);

  return (
    <div className={classnames}>
      <ToggleWindowContext.Provider value={{ currentFocus }}>
        {filterChildren}
      </ToggleWindowContext.Provider>
    </div>
  );
}
