import React, { ReactNode, useContext } from 'react';
import { classPrefix } from '../../../../const/common';
import { classNames } from '../../../../util/classnames';
import { ToggleWindowContext } from '../ToggleWindow';
import './ToggleWindowItem.less';

interface IToggleWindowItem {
  value?: string;
  isMobile?: boolean;
  children?: any;
  className?: string;
  updateCurrentFocus?: () => any;
  showSmallWindow?: boolean;
}

export default function ToggleWindowItem(props: IToggleWindowItem) {
  const {
    children, value, isMobile, updateCurrentFocus, showSmallWindow, className,
  } = props;
  const { currentFocus } = useContext(ToggleWindowContext);
  const isFocus = currentFocus === value;
  const classnames = classNames([
    className,
    `${classPrefix}-togglewindowitem-container`,
    `${classPrefix}-togglewindowitem-${isFocus ? 'big' : 'small'}`,
    { mobile: isMobile },
  ]);

  const render = () => {
    if (!isFocus && !showSmallWindow) {
      return null;
    }
    const comp = children ? React.cloneElement(children, { isSmall: !isFocus }) : null;
    return (
      <div
        onClick={() => !isFocus && updateCurrentFocus()}
        className={classnames}
      >
        {comp}
      </div>
    );
  };
  return <>{render()}</>;
}

ToggleWindowItem.displayName = 'ToggleWindowItem';
