import React, {
  useMemo,
  useContext,
  useState,
  useEffect,
} from 'react';
import {
  CallRole,
  CallStatus,
  CallMediaType,
  TUIGlobal,
  TUIStore,
  StoreName,
  NAME,
} from '../../../../TUICallService';
import { ButtonPanelConfig } from './config';
import ButtonPanelH5 from './ButtonPanelH5/ButtonPanelH5';
import ButtonPanelPC from './ButtonPanelPC/ButtonPanelPC';
import { CallInfoContext, IsClickableContext } from '../../../context';

const isMobile = !TUIGlobal.isPC;

export default function ButtonPanel() {
  const {
    callStatus, isGroupCall, callRole, callType,
  } = useContext(CallInfoContext);
  const [
    isClickable,
    setIsClickable,
  ] = useState(TUIStore.getData(StoreName.CALL, NAME.IS_CLICKABLE));
  const IsClickableContextValue = useMemo(() => isClickable, [isClickable]);
  const handleIsClickableChange = (value) => {
    setIsClickable(value);
  };
  useEffect(() => {
    TUIStore.watch(
      StoreName.CALL,
      { [NAME.IS_CLICKABLE]: handleIsClickableChange },
      { notifyRangeWhenWatch: NAME.MYSELF },
    );

    return () => {
      TUIStore.unwatch(
        StoreName.CALL,
        { [NAME.IS_CLICKABLE]: handleIsClickableChange },
      );
    };
  }, []);
  const buttons = useMemo(() => {
    const platform = TUIGlobal.isPC ? 'pc' : 'h5';
    const callScene = isGroupCall ? 'groupCall' : 'singleCall';
    const mediaType = callType === CallMediaType.AUDIO ? 'audio' : 'video';
    const status = callStatus === CallStatus.CALLING
      ? callRole === CallRole.CALLER ? 'calling' : 'accept'
      : callStatus;
    const rs = ButtonPanelConfig?.[platform]?.[callScene]?.[mediaType]?.[status] || [];
    if (rs.length === 1) {
      rs.unshift([]);
    }

    return rs;
  }, [isGroupCall, callType, callStatus, callRole]);

  return (
    <IsClickableContext.Provider value={IsClickableContextValue}>
      {isMobile ? <ButtonPanelH5 buttons={buttons} /> : <ButtonPanelPC buttons={buttons} />}
    </IsClickableContext.Provider>
  );
}
