import React, {
  useCallback,
  useContext,
  useMemo,
  useRef,
  useState,
} from 'react';
import Button from '../../../base/Button';
import Icon from '../../../base/Icon/Icon';
import { classNames } from '../../../../util/classnames';
import Popup from '../../../base/Popup/Popup';
import DeviceSelector from '../../DeviceSelector/DeviceSelector';
import { DeviceType } from '../../../../../TUICallService/const';
import { UserInfoContext } from '../../../../context';
import { TUICallKitServer, TUIGlobal, t } from '../../../../../TUICallService';
import useOnClickOutSide from '../../../base/hooks/useOnClickOutSide';
import CameraOpenSrc from '../../../../assets/button/camera-open.svg';
import CameraCloseSrc from '../../../../assets/button/camera-close.svg';
import ArrawSrc from '../../../../assets/button/desktop/arrow.png';
import './common.less';

interface ICameraProps {
  isMobile?: boolean;
}

export default function Camera(props: ICameraProps) {
  const { localUserInfo } = useContext(UserInfoContext);
  const [isShowDeviceList, setIsShowDeviceList] = useState(false);
  const arrowRef = useRef(null);
  const isCameraOpen = useMemo(
    () => localUserInfo?.isVideoAvailable,
    [localUserInfo?.isVideoAvailable],
  );
  const handleClick = useCallback(
    () => (isCameraOpen ? TUICallKitServer.closeCamera() : TUICallKitServer.openCamera('localVideo')),
    [isCameraOpen],
  );
  const iconClassName = classNames([
    'btn-icon-container',
    {
      mobile: !TUIGlobal.isPC,
      pc: TUIGlobal.isPC,
      close: !isCameraOpen,
    },
  ]);
  const CameraIcon = <Icon url={isCameraOpen ? CameraOpenSrc : CameraCloseSrc} className='btn-icon' />;
  const iconbtn = <Icon url={ArrawSrc} />;
  const btnText = isCameraOpen ? t('camera enabled') : t('camera disabled');

  useOnClickOutSide([arrowRef], () => {
    setIsShowDeviceList(false);
  });

  return (
    <>
      <Popup visible={isShowDeviceList} content={<DeviceSelector deviceType={DeviceType.CAMERA} />}>
        <div style={{ display: 'flex' }}>
          <Button
            className='btn'
            iconClassName={iconClassName}
            icon={CameraIcon}
            onClick={handleClick}
            {...props}
          >
            {btnText}
          </Button>
        </div>
      </Popup>
      {TUIGlobal.isPC && (
        <Button
          ref={arrowRef}
          className='arrow-btn'
          icon={iconbtn}
          onClick={() => setIsShowDeviceList(!isShowDeviceList)}
        />
      )}
    </>
  );
}
