import React, { useContext } from 'react';
import { TUICallKitServer, TUIGlobal, t } from '../../../../../../TUICallService';
import Button from '../../../../base/Button';
import Icon from '../../../../base/Icon/Icon';
import { classNames } from '../../../../../util/classnames';
import HangupSrc from '../../../../../assets/button/hangup.svg';
import { IsClickableContext } from '../../../../../context';
import './Hangup.less';

interface IHangupProps {
  isMobile?: boolean;
}

export default function Hangup(props: IHangupProps) {
  const isClickable = useContext(IsClickableContext);
  const handleClick = () => TUICallKitServer.hangup();
  const iconClassName = classNames([
    'btn-icon-container',
    'hangup',
    {
      mobile: !TUIGlobal.isPC,
      pc: TUIGlobal.isPC,
    },
  ]);
  const hangupIcon = <Icon className='btn-icon' url={HangupSrc} />;
  return (
    <Button
      loading={!isClickable}
      className='btn'
      iconClassName={iconClassName}
      icon={hangupIcon}
      onClick={handleClick}
      {...props}
    >
      {t('hangup')}
    </Button>
  );
}
