import React, {
  useCallback,
  useContext,
  useMemo,
  useState,
  useRef,
} from 'react';
import Button from '../../../base/Button';
import Icon from '../../../base/Icon/Icon';
import { TUICallKitServer, TUIGlobal, t } from '../../../../../TUICallService';
import useOnClickOutSide from '../../../base/hooks/useOnClickOutSide';
import { UserInfoContext } from '../../../../context';
import { classNames } from '../../../../util/classnames';
import Popup from '../../../base/Popup/Popup';
import DeviceSelector from '../../DeviceSelector/DeviceSelector';
import { DeviceType } from '../../../../../TUICallService/const';
import ArrawSrc from '../../../../assets/button/desktop/arrow.png';
import MicrophoneOpenSrc from '../../../../assets/button/microphone-open.svg';
import MicrophoneCloseSrc from '../../../../assets/button/microphone-close.svg';
import './common.less';

interface IMicrophoneProps {
  isMobile?: boolean;
}

export default function Microphone(props: IMicrophoneProps) {
  const { localUserInfo } = useContext(UserInfoContext);
  const arrowRef = useRef(null);
  const [isShowDeviceList, setIsShowDeviceList] = useState(false);
  const isOpen = useMemo(() => localUserInfo?.isAudioAvailable, [localUserInfo]);
  const handleClick = useCallback(
    () => (isOpen ? TUICallKitServer.closeMicrophone() : TUICallKitServer.openMicrophone()),
    [isOpen],
  );
  const iconClassName = classNames([
    'btn-icon-container',
    {
      mobile: !TUIGlobal.isPC,
      pc: TUIGlobal.isPC,
      close: !isOpen,
    },
  ]);
  const btnText = isOpen ? t('microphone enabled') : t('microphone disabled');
  const iconbtn = <Icon url={ArrawSrc} />;
  const MicrophoneIcon = <Icon className='btn-icon' url={isOpen ? MicrophoneOpenSrc : MicrophoneCloseSrc}/>;
  useOnClickOutSide([arrowRef], () => {
    setIsShowDeviceList(false);
  });
  return (
    <>
      <Popup
        visible={isShowDeviceList}
        content={<DeviceSelector deviceType={DeviceType.MICROPHONE} />}
      >
        <div style={{ display: 'flex' }}>
          <Button
            className='btn'
            iconClassName={iconClassName}
            icon={MicrophoneIcon}
            onClick={handleClick}
            {...props}
          >
            {btnText}
          </Button>
        </div>
      </Popup>
      {TUIGlobal.isPC && (
      <Button ref={arrowRef} className='arrow-btn' icon={iconbtn} onClick={() => setIsShowDeviceList(!isShowDeviceList)} />
      )}
    </>
  );
}
