import React, { useState } from 'react';
import Button from '../../../base/Button';
import { TUIGlobal, t } from '../../../../../TUICallService/index';
import Icon from '../../../base/Icon/Icon';
import { classNames } from '../../../../util/classnames';
import Popup from '../../../base/Popup/Popup';
import DeviceSelector from '../../DeviceSelector/DeviceSelector';
import { DeviceType } from '../../../../../TUICallService/const';
import useDeviceList from '../../../../hooks/useDeviceList';
import SpeakerOpenSrc from '../../../../assets/button/speaker-open.svg';

interface ISpeakerProps {
  isMobile?: boolean;
}

export default function Speaker(props: ISpeakerProps) {
  const [visible, setVisible] = useState(false);
  const [{ deviceList, currentDeviceId }] = useDeviceList(DeviceType.SPEAKER);

  const getLabelByDeviceId = (deviceId: any) => {
    const result = deviceList.find(item => item.deviceId === deviceId);
    return result ? result.label : t('speaker phone');
  };

  const SpeakerIcon = (
    <Icon
      className='btn-icon'
      url={SpeakerOpenSrc}
    />
  );
  const iconClassName = classNames([
    'btn-icon-container',
    {
      mobile: !TUIGlobal.isPC,
      pc: TUIGlobal.isPC,
    },
  ]);

  const onVisibleChange = (e) => {
    setVisible(e);
  };

  return (
    <Popup
      visible={visible}
      onVisibleChange={onVisibleChange}
      content={<DeviceSelector isShowControlBtn={false} deviceType={DeviceType.SPEAKER} />}
    >
      <Button
        className='btn'
        iconClassName={iconClassName}
        icon={SpeakerIcon}
        onClick={() => setVisible((state) => !state)}
        {...props}
      >
        {getLabelByDeviceId(currentDeviceId)}
      </Button>
    </Popup>
  );
}
