import React, { useContext } from 'react';
import { DeviceType } from '../../../../TUICallService/const';
import useDeviceList from '../../../hooks/useDeviceList';
import { TUICallKitServer, t } from '../../../../TUICallService';
import { classNames } from '../../../util/classnames';
import { UserInfoContext } from '../../../context';
import './DeviceSelector.less';

interface IDeviceSelectorProps {
  deviceType?: DeviceType;
  isShowControlBtn?: boolean;
}

export default function DeviceSelector(props: IDeviceSelectorProps) {
  const { deviceType, isShowControlBtn = true } = props;
  const { localUserInfo } = useContext(UserInfoContext);
  const [{ deviceList, currentDeviceId }, { setCurrentDeviceId }] = useDeviceList(deviceType);
  const handleClickDeviceItem = async (deviceId: string) => {
    try {
      await TUICallKitServer.switchDevice({
        deviceType,
        deviceId,
      });
      setCurrentDeviceId(deviceId);
    } catch (err) {
      console.debug(err);
    }
  };
  const switchStatus = async () => {
    if (deviceType === DeviceType.CAMERA) {
      if (localUserInfo?.isVideoAvailable) {
        await TUICallKitServer.closeCamera();
      } else {
        await TUICallKitServer.openCamera('localVideo');
      }
    }

    if (deviceType === DeviceType.MICROPHONE) {
      if (localUserInfo?.isAudioAvailable) {
        await TUICallKitServer.closeMicrophone();
      } else {
        await TUICallKitServer.openMicrophone();
      }
    }
  };
  const DeviceText = () => {
    if (deviceType === DeviceType.CAMERA) {
      return localUserInfo?.isVideoAvailable ? t('close camera') : t('open camera');
    }

    if (deviceType === DeviceType.MICROPHONE) {
      return localUserInfo?.isAudioAvailable ? t('close microphone') : t('open microphone');
    }
  };
  function renderDeviceList() {
    if (deviceList?.length > 0) {
      return deviceList?.map((device) => {
        const { deviceId, label } = device;
        return (
          <div
            className={classNames([
              'device-item',
              { select: currentDeviceId === deviceId },
            ])}
            key={deviceId}
            onClick={() => handleClickDeviceItem(deviceId)}
          >
            {label}
          </div>
        );
      });
    }
    return <div className='device-item'>{t('failed to obtain speakers')}</div>;
  }

  return (
    <div className='device-selector-container'>
      <div className='scroll-container'>
        <div className='scroll-content'>
          {renderDeviceList()}
        </div>
      </div>
      {isShowControlBtn && <div onClick={switchStatus} className='device-item control-item'>{DeviceText()}</div>}
    </div>
  );
}
