import React, { ReactNode, useContext } from 'react';
import { classNames } from '../../../../../util/classnames';
import Icon from '../../../../base/Icon/Icon';
import { CallInfoContext, UserInfoContext } from '../../../../../context';
import useCallDuration from '../../../../../hooks/useCallDuration';
import { CallStatus, t, TUICallKitServer } from '../../../../../../TUICallService';
// @ts-ignore
import EarphoneSrc from '../../../../../assets/floatingWindow/mobile/earphone.svg';
// @ts-ignore
import CameraOpenSrc from '../../../../../assets/floatingwindow/mobile/camera-open.svg';
// @ts-ignore
import MicrophoneOpenSrc from '../../../../../assets/floatingwindow/mobile/microphone-open.svg';
// @ts-ignore
import CameraCloseSrc from '../../../../../assets/floatingwindow/mobile/camera-close.svg';
// @ts-ignore
import MicrophoneCloseSrc from '../../../../../assets/floatingwindow/mobile/microphone-close.svg';
import './FloatingWindowH5GroupCall.less';

interface IFloatingWindowH5Props {
  showVideo?: boolean;
  hasVideo?: boolean;
  children?: ReactNode;
}

export default function FloatingWindowH5GroupCall(props: IFloatingWindowH5Props) {
  const { hasVideo } = props;
  const { isGroupCall, callStatus } = useContext(CallInfoContext);
  const { isFloat } = useContext(CallInfoContext);
  const { localUserInfo: { isAudioAvailable, isVideoAvailable } } = useContext(UserInfoContext);
  const duration = useCallDuration();
  const cameraSrc = isVideoAvailable ? CameraOpenSrc : CameraCloseSrc;
  const microphoneSrc = isAudioAvailable ? MicrophoneOpenSrc : MicrophoneCloseSrc;

  const renderCallStatus = () => {
    const classnames = classNames([
      'video-stream',
      {
        hidden: !hasVideo,
      },
    ]);
    return (
      <>
        <div
          onClick={() => TUICallKitServer.toggleMinimize()}
          className={classnames}
          id='float'
        />
        {!hasVideo && (
          <div className='audio-stream'>
            <div className='earphone'><Icon url={EarphoneSrc} /></div>
            <div className='info'>
              {callStatus === CallStatus.CONNECTED ? duration : t('wait to be called')}
            </div>
          </div>
        )}
      </>
    );
  };

  return (
    <div onClick={() => TUICallKitServer.toggleMinimize()} className='floating-window-h5-groupcall-container'>
      <div className='click-overlay' />
      <div className={classNames(['call-status', { float: isFloat, video: hasVideo }])}>
        {renderCallStatus()}
      </div>
      {isGroupCall && isFloat && (
        <div className='device-status'>
          <div className='icon camera'>
            <Icon url={cameraSrc} />
          </div>
          <div className='icon micphone'>
            <Icon url={microphoneSrc} />
          </div>
        </div>
      )}
    </div>
  );
}
