import React, { ReactNode, useContext } from 'react';
import { classNames } from '../../../../../util/classnames';
import Icon from '../../../../base/Icon/Icon';
import { CallInfoContext } from '../../../../../context';
import useCallDuration from '../../../../../hooks/useCallDuration';
import {
  CallMediaType, CallStatus, TUICallKitServer, t,
} from '../../../../../../TUICallService';
import EarphoneSrc from '../../../../../assets/floatingWindow/mobile/earphone.svg';
import './FloatingWindowH5SingleCall.less';

interface IFloatingWindowH5Props {
  showVideo?: boolean;
  enable?: boolean;
  hasVideo?: boolean;
  children?: ReactNode;
}

export default function FloatingWindowH5SingleCall(props: IFloatingWindowH5Props) {
  const { hasVideo } = props;
  const { callStatus, callType } = useContext(CallInfoContext);
  const { isFloat } = useContext(CallInfoContext);
  const duration = useCallDuration();

  const renderCallStatus = () => {
    const classnames = classNames([
      'video-stream',
      {
        hidden: !hasVideo,
      },
    ]);
    return (
      <>
        <div onClick={() => TUICallKitServer.toggleMinimize()} className={classnames} id='float' />
        {!hasVideo ? (
          <div className='audio-stream'>
            <div className='earphone'><Icon url={EarphoneSrc} /></div>
            <div className='info'>
              {callStatus === CallStatus.CONNECTED ? duration : t('wait to be called')}
            </div>
          </div>
        ) : (
          <div className='info'>
            {callStatus === CallStatus.CONNECTED ? '' : t('wait to be called')}
          </div>
        )}
      </>
    );
  };

  const classnames = classNames([
    'floating-window-h5-singlecall-container',
    { 'audio-call': callType === CallMediaType.AUDIO },
  ]);

  return (
    <div onClick={() => TUICallKitServer.toggleMinimize()} className={classnames}>
      <div className='click-overlay' />
      <div className={classNames(['call-status', { float: isFloat, video: hasVideo }])}>
        {renderCallStatus()}
      </div>
    </div>
  );
}
