import React, { useEffect, useState } from 'react';
import { classNames } from '../../../../util/classnames';
import Col from '../../../base/Grid/Col';
import Row from '../../../base/Grid/Row';
import Icon from '../../../base/Icon/Icon';
import { TUICallKitServer } from '../../../../../TUICallService';
import FloatCallEnd from '../../../../assets/floatingWindow/desktop/floatCallEnd.svg';
import FloatMicrophoneSVG from '../../../../assets/floatingWindow/desktop/floatMicrophone.svg';
import FloatMicrophoneClosedSVG from '../../../../assets/floatingWindow/desktop/floatMicrophoneClosed.svg';
import FloatFullScreenSVG from '../../../../assets/floatingWindow/desktop/floatFullScreen.svg';
import './FloatingWindowPC.less';

interface IFloatingWindowPCProps {
  isAudioAvailable?: boolean;
}

export default function FloatingWindowPC(props: IFloatingWindowPCProps) {
  const { isAudioAvailable } = props;
  const [microphoneSrc, setMicrophoneSrc] = useState(FloatMicrophoneSVG);
  const calssnames = classNames([
    'floatingwindow-pc-container',
  ]);

  useEffect(() => {
    const microphoneSrc = isAudioAvailable ? FloatMicrophoneSVG : FloatMicrophoneClosedSVG;
    setMicrophoneSrc(microphoneSrc);
  }, [isAudioAvailable]);

  const hangup = () => TUICallKitServer.hangup();
  const toggleMicrophone = () => (isAudioAvailable
    ? TUICallKitServer.closeMicrophone()
    : TUICallKitServer.openMicrophone());
  const closeFloatingWindow = () => TUICallKitServer.toggleMinimize();
  return (
    <div className={calssnames}>
      <Row>
        <Col span={4} align='center'>
          <Icon className='floatingwindow-icon' url={FloatCallEnd} onClick={hangup} />
        </Col>
        <Col span={4} align='center'>
          <Icon className='floatingwindow-icon' url={microphoneSrc} onClick={toggleMicrophone} />
        </Col>
        <Col span={4} align='center'>
          <Icon className='floatingwindow-icon' url={FloatFullScreenSVG} onClick={closeFloatingWindow} />
        </Col>
      </Row>
    </div>
  );
}
