import React, { CSSProperties, ReactNode } from 'react';
import Overlayer from '../../base/Overlayer/Overlayer';
import Avatar from '../../base/Avatar';
import Loading from '../../base/Loading';
import { classNames } from '../../../util/classnames';
import MicrophoneVolumn from '../MicrophoneVolumn/MicrophoneVolumn';
import './OverlayStream.less';

interface IOverlayStreamProps {
  avatar?: string;
  username?: string;
  isMobile?: boolean;
  blur?: boolean;
  showAvatar?: boolean;
  showUsername?: boolean;
  theme?: 'circle' | 'dot';
  style?: CSSProperties;
  showOverlayer?: boolean;
  showLoading?: boolean;
  showBackground?: boolean;
  className?: string;
  showTip?: boolean;
  showVolumn?: boolean;
  volume?: number;
  isMute?: boolean;
  tip?: string;
  isSmall?: boolean;
  children?: ReactNode;
}

export default function OverlayStream(props: IOverlayStreamProps) {
  const {
    avatar,
    username,
    isMobile,
    isSmall,
    blur = true,
    theme = 'circle',
    children,
    className,
    tip = '',
    volume,
    isMute = false,
    showAvatar = true,
    showUsername = true,
    showOverlayer = true,
    showBackground = true,
    showLoading = true,
    showTip = true,
    showVolumn = false,
    style = {},
  } = props;
  const classnames = classNames([
    className,
    'overlay-stream-container',
    {
      mobile: isMobile,
      pc: !isMobile,
    },
  ]);

  return (
    <div className={classnames} style={style}>
      <Loading showLoading={showLoading} size={40} theme={theme} showOverlayer={false}>
        <div className='user-info-container'>
          {showAvatar && <Avatar className={classNames(['avatar', { small: isSmall }])} image={avatar} />}
          {showUsername && (
            <div className='name'>
              {username}
              {showVolumn && <MicrophoneVolumn volume={volume} close={isMute} style={{ marginLeft: '10px' }} />}
            </div>
          )}
          {showTip && <div className='tip'>{tip}</div>}
          {children}
        </div>
        {showBackground && (
          <Overlayer
            showOverlayer={showOverlayer}
            className={classNames({ blur })}
            background={avatar}
          />
        )}
      </Loading>
    </div>
  );
}
