import React, { CSSProperties } from 'react';
import { IUserInfo } from '../../../../TUICallService/interface';
import StreamInfo from '../StreamInfo';
import { classNames } from '../../../util/classnames';
import useGetVolumeMap from '../../../hooks/useGetVolumeMap';
import './Player.less';

interface IPlayer {
  streamInfo?: IUserInfo;
  style?: CSSProperties;
  showStreamInfo?: boolean;
  loading?: boolean;
  renderLoading?: (params?: any) => any;
  renderAudioStream?: (params?: any) => any;
  className?: string;
  isSpkear?: boolean;
}

export default function Player(props: IPlayer) {
  const volumnMap = useGetVolumeMap();
  const {
    streamInfo = {},
    showStreamInfo = true,
    isSpkear,
    style,
    renderAudioStream,
    className,
    loading,
    renderLoading,
  } = props;
  const {
    domId,
    isAudioAvailable,
    userId,
  } = streamInfo as IUserInfo;

  const classnames = classNames([
    className,
    'player-container',
  ]);

  return (
    <div id={domId} style={style} className={classnames}>
      {!loading && renderAudioStream?.({
        volume: volumnMap[domId],
        isMute: !isAudioAvailable,
      })}
      {loading && renderLoading?.()}
      {showStreamInfo && (
        <StreamInfo
          volume={volumnMap[domId]}
          isSpkear={isSpkear}
          isMute={!isAudioAvailable}
          displayName={userId}
        />
      )}
    </div>
  );
}
