import React, { CSSProperties, useContext } from 'react';
import { CallMediaType, CallStatus, t } from '../../../../TUICallService';
import { UserInfoContext } from '../../../context';
import StreamInfo from '../StreamInfo';
import { classNames } from '../../../util/classnames';
import useGetVolumeMap from '../../../hooks/useGetVolumeMap';
import './Pusher.less';

interface IPusher {
  style?: CSSProperties;
  showStreamInfo?: boolean;
  callType?: CallMediaType;
  callStatus?: CallStatus;
  loading?: boolean;
  renderLoading?: Function;
  isSmall?: boolean;
  renderAudioStream?: Function;
  isSpkear?: boolean;
  className?: string;
}

const Pusher = React.memo((props: IPusher) => {
  const {
    loading = true,
    renderLoading,
    renderAudioStream,
    isSpkear,
    className,
    showStreamInfo = true,
  } = props;
  const { localUserInfo: { domId, userId, isAudioAvailable } } = useContext(UserInfoContext);
  const volumnMap = useGetVolumeMap();
  const classnames = classNames([
    className,
    'puhser-container',
  ]);

  return (
    <div id={domId} className={classnames}>
      {!loading && renderAudioStream?.()}
      {loading && renderLoading?.()}
      {showStreamInfo && (
        <StreamInfo
          volume={volumnMap[domId]}
          isSpkear={isSpkear}
          isMute={!isAudioAvailable}
          displayName={`(${userId})${t('me')}`}
        />
      )}
    </div>
  );
});

export default Pusher;
