import React, { useContext } from 'react';
import Icon from '../../../base/Icon/Icon';
import { classNames } from '../../../../util/classnames';
import Row from '../../../base/Grid/Row';
import Col from '../../../base/Grid/Col';
import { CallInfoContext } from '../../../../context';
import VolumnSrc from '../../../../assets/streamInfo/mobile/volumn.svg';
import MicrophoneCloseGroupSrc from '../../../../assets/streamInfo/mobile/microphone-close-group.svg';
import MicrophoneCloseSingleSrc from '../../../../assets/streamInfo/mobile/microphone-close-single.svg'
import './StreamInfoH5.less';

interface IStreamInfoH5Props {
  isSpkear?: boolean;
  isMute?: boolean;
  username?: string;
  showUserName?: boolean;
}

export default function StreamInfoH5(props: IStreamInfoH5Props) {
  const { isSpkear, isMute, username, showUserName = false } = props;
  const { isGroupCall } = useContext(CallInfoContext);
  const classnames = classNames(
    [
      'stream-info-container-h5',
      {
        group: isGroupCall,
        single: !isGroupCall,
      },
    ],
  );

  const renderGroupCallStreamInfo = () => (
    <Row>
      <Col span={6} justify='start'>
        {isSpkear && <Icon style={{ width: 'fit-content' }} url={VolumnSrc} />}
      </Col>
      <Col span={6} justify='end'>
        {isMute && <Icon style={{ width: 'fit-content' }} url={MicrophoneCloseGroupSrc} />}
      </Col>
    </Row>
  );
  const renderSingleCallStreamInfo = () => (
    <Row>
      <Col span={12} justify='start'>
        {isMute && <Icon style={{ width: 'fit-content' }} url={MicrophoneCloseSingleSrc} />}
      </Col>
    </Row>
  );

  return (
    <div className={classnames}>
      {isGroupCall ? renderGroupCallStreamInfo() : renderSingleCallStreamInfo()}
    </div>
  );
}
