import React, { CSSProperties, useEffect, useState } from 'react';
import { Message } from '../../base/Message/Message';
import { classNames } from '../../../util/classnames';
import { NAME, StoreName, TUIStore } from '../../../../TUICallService';

interface ITipProps {
  className?: string;
  style?: CSSProperties;
}

export default function Tip(props: ITipProps) {
  const { className, style } = props;
  const [tip, setTip] = useState(null);
  const [show, setShow] = useState(true);
  const [showDuration, setShowDuration] = useState(0);

  const classnames = classNames([
    'tip-container',
    className,
  ]);

  function handleCallTipsChange(value) {
    setShowDuration(0);
    setTip(value);
  }
  function handleToastInfoChange(value) {
    let text = value;

    if (typeof text === 'object') {
      text = value?.text;
    }

    if (text) {
      setShowDuration(2000);
      setTip(text);
    }
  }

  useEffect(() => {
    TUIStore.watch(
      StoreName.CALL,
      {
        [NAME.CALL_TIPS]: handleCallTipsChange,
      },
      {
        notifyRangeWhenWatch: NAME.MYSELF,
      },
    );

    TUIStore.watch(
      StoreName.CALL,
      {
        [NAME.TOAST_INFO]: handleToastInfoChange,
      },
    );

    return () => {
      TUIStore.unwatch(
        StoreName.CALL,
        {
          [NAME.CALL_TIPS]: handleCallTipsChange,
          [NAME.TOAST_INFO]: handleToastInfoChange,
        },
      );
    };
  }, []);

  return (
    <div className={classnames} style={style}>
      {show && (
      <Message style={{ whiteSpace: 'nowrap' }} duration={showDuration} onClose={() => setShow(false)} plaintext>
        {tip}
      </Message>
      )}
    </div>
  );
}
